Module: OfferEngine

Defined in:
lib/reg_path/offer_engine/client.rb,
lib/reg_path/properties.rb,
lib/reg_path/offer_engine/models/user.rb,
lib/reg_path/offer_engine/models/offer.rb,
lib/reg_path/offer_engine/models/reg_path.rb,
lib/reg_path/offer_engine/models/submission.rb

Overview

The OfferEngineClient class provides an interface for connecting to the OfferEngine.

It exposes two main methods, get_next_offers and submit_to_offer_engine which are resposible for requesting and sending data to/from the server.

Defined Under Namespace

Modules: Models, Properties Classes: Client